Imports System
Imports System.Data

Public Class DummyDataCreator
#Region " Private Members "
    Private Shared rnd As Random = New Random()
#End Region

#Region " Enums "
    Public Enum Element
        Air
        Earth
        Fire
        Water
        Energy
    End Enum
#End Region

#Region " GetData "
    Public Shared Function GetData(ByVal rows As Integer, ByVal types() As Type) As DataTable
        Dim ReturnValue As New DataTable()
        Dim typeCounts As New System.Collections.Hashtable()
        Dim keyColumn As DataColumn

        keyColumn = ReturnValue.Columns.Add("Key", GetType(Integer))
        keyColumn.AutoIncrement = True
        keyColumn.ReadOnly = True

        Dim aType As Type

        For Each aType In types
            If (typeCounts.ContainsKey(aType.Name)) Then
                typeCounts(aType.Name) = CType(typeCounts(aType.Name) + 1, Integer)
            Else
                typeCounts.Add(aType.Name, 1)
            End If
            ReturnValue.Columns.Add(aType.Name + " " + typeCounts(aType.Name).ToString(), aType)
        Next

        Dim i As Integer
        For i = 0 To rows - 1
            Dim newRow As DataRow = ReturnValue.NewRow()
            newRow("Key") = i
            Dim dc As DataColumn
            For Each dc In ReturnValue.Columns
                If (dc.DataType Is GetType(String)) Then
                    newRow(dc.ColumnName) = RandomString()
                ElseIf (dc.DataType Is GetType(Integer) And dc.ColumnName <> "Key") Then
                    newRow(dc.ColumnName) = RandomInt()
                ElseIf (dc.DataType Is GetType(Boolean)) Then
                    newRow(dc.ColumnName) = RandomBool()
                ElseIf (dc.DataType Is GetType(Double)) Then
                    newRow(dc.ColumnName) = RandomDouble()
                ElseIf (dc.DataType Is GetType(Element)) Then
                    newRow(dc.ColumnName) = RandomElement()
                ElseIf (dc.DataType Is GetType(DateTime)) Then
                    newRow(dc.ColumnName) = RandomDate()
                ElseIf (dc.DataType Is GetType(Decimal)) Then
                    newRow(dc.ColumnName) = RandomDecimal()
                End If
            Next

            ReturnValue.Rows.Add(newRow)
        Next

        ReturnValue.AcceptChanges()
        Return ReturnValue
    End Function

    Public Shared Function GetData(ByVal rows As Integer) As DataTable
        Dim types() As System.Type = New Type() _
                  {GetType(String), _
                   GetType(String), _
                   GetType(Boolean), _
                   GetType(Boolean), _
                   GetType(Integer), _
                   GetType(Integer), _
                   GetType(Double), _
                   GetType(Double), _
                   GetType(Decimal), _
                   GetType(Decimal), _
                   GetType(DateTime), _
                   GetType(DateTime), _
                   GetType(Element), _
                   GetType(Element)}
        Return GetData(rows, types)
    End Function


    Public Shared Function GetData() As DataTable
        Return GetData(100)
    End Function


#End Region

#Region " RandomString "
    Public Shared Function RandomString(ByVal characterCount As Integer) As String
        If (characterCount < 1) Then
            characterCount = rnd.Next(1, 51)
        End If

        Dim SB As New System.Text.StringBuilder()

        Dim i As Integer
        For i = 1 To characterCount
            SB.Append(RandomCharacter())
        Next

        Return SB.ToString()
    End Function


    Public Shared Function RandomString() As String
        Return RandomString(-1)
    End Function

#End Region

#Region " RandomCharacter "
    Public Shared Function RandomCharacter() As Char
        Dim ReturnValue As Char
        ReturnValue = Chr(rnd.Next(65, 91))

        If (RandomBool()) Then
            ReturnValue = Char.ToLower(ReturnValue)
        End If
        Return ReturnValue
    End Function
#End Region

#Region " RandomBool "

    Public Shared Function RandomBool() As Boolean
        If (RandomInt(0, 1) = 1) Then
            Return True
        Else
            Return False
        End If
    End Function

#End Region

#Region " RandomInt "
    Public Shared Function RandomInt(ByVal Min As Integer, ByVal Max As Integer) As Integer
        Return rnd.Next(Min, Max + 1)
    End Function

    Public Shared Function RandomInt() As Integer
        Return RandomInt(-100, 100)
    End Function

#End Region

#Region " RandomDouble "
    Public Shared Function RandomDouble() As Double
        Return rnd.NextDouble() * 100
    End Function
#End Region

#Region " RandomDecimal "
    Public Shared Function RandomDecimal() As Decimal
        Return CType(rnd.NextDouble() * 100, Decimal)
    End Function
#End Region

#Region " RandomDate "
    Public Shared Function RandomDate() As DateTime
        Dim ReturnValue As DateTime = System.DateTime.Today
        ReturnValue = ReturnValue.AddYears(RandomInt())
        ReturnValue = ReturnValue.AddMonths(RandomInt())
        ReturnValue = ReturnValue.AddDays(RandomInt())
        ReturnValue = ReturnValue.AddHours(RandomInt())
        ReturnValue = ReturnValue.AddSeconds(RandomInt())
        ReturnValue = ReturnValue.AddMinutes(RandomInt())
        Return ReturnValue
    End Function
#End Region

#Region " Random Element "
    Public Shared Function RandomElement() As Element
        Return CType(rnd.Next(0, System.Enum.GetValues(GetType(Element)).Length), Element)
    End Function
#End Region
End Class

